import { type Constraint, type NodeSchema } from "@ark/schema";
import type { Module, Submodule } from "../../module.ts";
import type { AtLeastLength, AtMostLength, Branded, Constraints, ExactlyLength, LessThanLength, Matching, MoreThanLength, Narrowed, constrain, normalizePrimitiveConstraintRoot } from "../ast.ts";
import { alpha } from "./alpha.ts";
import { alphanumeric } from "./alphanumeric.ts";
import { capitalize } from "./capitalize.ts";
import { creditCard } from "./creditCard.ts";
import { date } from "./date.ts";
import { digits } from "./digits.ts";
import { email } from "./email.ts";
import { integer } from "./integer.ts";
import { ip } from "./ip.ts";
import { json } from "./json.ts";
import { lower } from "./lower.ts";
import { normalize } from "./normalize.ts";
import { numeric } from "./numeric.ts";
import { semver } from "./semver.ts";
import { trim } from "./trim.ts";
import { upper } from "./upper.ts";
import { uuid } from "./uuid.ts";
export declare const string: Module<string.submodule>;
export declare namespace string {
    type atLeastLength<rule> = constrain<string, AtLeastLength<rule>>;
    type moreThanLength<rule> = constrain<string, MoreThanLength<rule>>;
    type atMostLength<rule> = constrain<string, AtMostLength<rule>>;
    type lessThanLength<rule> = constrain<string, LessThanLength<rule>>;
    type exactlyLength<rule> = constrain<string, ExactlyLength<rule>>;
    type matching<rule> = constrain<string, Matching<rule>>;
    type narrowed = constrain<string, Narrowed>;
    type branded<rule> = constrain<string, Branded<rule>>;
    type is<constraints extends Constraints> = constrain<string, constraints>;
    type parseConstraint<kind extends Constraint.PrimitiveKind, schema extends NodeSchema<kind>> = normalizePrimitiveConstraintRoot<schema> extends infer rule ? kind extends "minLength" ? schema extends {
        exclusive: true;
    } ? moreThanLength<rule> : atLeastLength<rule> : kind extends "maxLength" ? schema extends {
        exclusive: true;
    } ? lessThanLength<rule> : atMostLength<rule> : kind extends "pattern" ? matching<rule & string> : kind extends "exactLength" ? exactlyLength<rule> : narrowed : never;
    type submodule = Submodule<{
        $root: string;
        alpha: alpha;
        alphanumeric: alphanumeric;
        digits: digits;
        numeric: numeric;
        integer: integer;
        creditCard: creditCard;
        email: email;
        uuid: uuid;
        semver: semver;
        ip: ip;
        json: json;
        date: date;
        trim: trim;
        normalize: normalize;
        capitalize: capitalize;
        lower: lower;
        upper: upper;
    }>;
}
